<?php

namespace Btravel\Search\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Search\Http\Requests\SearchRequest;
use Btravel\Search\Interfaces\SearchRepositoryInterface;
use Btravel\Search\Models\Search;
use Btravel\Search\Forms\Search as Form;

/**
 * APIController  class for search.
 */
class SearchAPIController extends BaseController
{

    /**
     * Initialize search resource controller.
     *
     * @param type SearchRepositoryInterface $search
     *
     * @return null
     */
    public function __construct(SearchRepositoryInterface $search)
    {
        parent::__construct();
        $this->repository = $search;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Search\Repositories\Criteria\SearchResourceCriteria::class);
    }

    /**
     * Display a list of search.
     *
     * @return Response
     */
    public function index(SearchRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Search\Repositories\Presenter\SearchPresenter::class)
            ->paginate();
    }

    /**
     * Display search.
     *
     * @param Request $request
     * @param Model   $search
     *
     * @return Response
     */
    public function show(SearchRequest $request, Search $search)
    {
        return $search->setPresenter(\Btravel\Search\Repositories\Presenter\SearchListPresenter::class);
        ;
    }

    /**
     * Create new search.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SearchRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('search::search.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('search/search/' . $search->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/search');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the search.
     *
     * @param Request $request
     * @param Model   $search
     *
     * @return Response
     */
    public function update(SearchRequest $request, Search $search)
    {
        try {
            $data = $request->all();

            $search->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('search::search.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('search/search/' . $search->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/search/' . $search->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the search.
     *
     * @param Model   $search
     *
     * @return Response
     */
    public function destroy(SearchRequest $request, Search $search)
    {
        try {
            $search->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('search::search.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('search/search/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/search/' . $search->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
