<?php

namespace Btravel\Search\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Btravel\Search\Interfaces\SearchRepositoryInterface;

class SearchPublicController extends BaseController
{
    // use SearchWorkflow;

    /**
     * Constructor.
     *
     * @param type \Btravel\Search\Interfaces\SearchRepositoryInterface $search
     *
     * @return type
     */
    public function __construct(SearchRepositoryInterface $search)
    {
        $this->repository = $search;
        parent::__construct();
    }

    /**
     * Show search's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $searches = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('search::search.names'))
            ->view('search::public.search.index')
            ->data(compact('searches'))
            ->output();
    }


    /**
     * Show search.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $search = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($search->name . trans('search::search.name'))
            ->view('search::public.search.show')
            ->data(compact('search'))
            ->output();
    }

}
