<?php

namespace Btravel\Search\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Search\Models\Search;

class SearchPolicy
{

    /**
     * Determine if the given user can view the search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function view(UserPolicy $user, Search $search)
    {
        if ($user->canDo('search.search.view') && $user->isAdmin()) {
            return true;
        }

        return $search->user_id == user_id() && $search->user_type == user_type();
    }

    /**
     * Determine if the given user can create a search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('search.search.create');
    }

    /**
     * Determine if the given user can update the given search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function update(UserPolicy $user, Search $search)
    {
        if ($user->canDo('search.search.edit') && $user->isAdmin()) {
            return true;
        }

        return $search->user_id == user_id() && $search->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Search $search)
    {
        return $search->user_id == user_id() && $search->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Search $search)
    {
        if ($user->canDo('search.search.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given search.
     *
     * @param UserPolicy $user
     * @param Search $search
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Search $search)
    {
        if ($user->canDo('search.search.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
